==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/he.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "דואר",
    "Loading accounts" : "אנשי הקשר נטענים",
    "Error while loading the accounts." : "שגיאה בזמן העלאת החשבונות.",
    "Can not load this folder." : "לא ניתן לטעון את התיקייה הזאת.",
    "Searching for {query}" : "מתבצע חיפוש אחר {query}",
    "Error while deleting message." : "שגיאה בזמן מחיקת הודעה.",
    "Forwarded message" : "הודעה שקודמה",
    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
    "Attachments saved to Files." : "שבצים מצורפים נשמרו לקטגוריית קבצים.",
    "Attachment saved to Files." : "קובץ מצורף נשמר לקטגוריית קבצים.",
    "Error while saving attachments to Files." : "שגיאה בזמן שמירת קבצים מצורפים לקטגוריית קבצים.",
    "Error while saving attachment to Files." : "שגיאה בזמן שמירת קובץ מצורף לקטגוריית קבצים.",
    "Message flag could not be set." : "לא ניתן היה להגדיר דגל להודעה",
    "Could not move message." : "לא ניתן להעביר את ההודעה.",
    "Invalid account" : "חשבון לא חוקי",
    "Invalid folder" : "תיקייה לא חוקית",
    "Error while creating the account: " : "שגיאה בעת יצירת החשבון:",
    "Unknown error" : "שגיאה בלתי ידועה",
    "Error while updating the account: " : "אירעה שגיאה בעת עדכון החשבון:",
    "All inboxes" : "כל תיבות דואר נכנס",
    "you" : "את/ה",
    "Send message to {email}" : "שליחת הודעה אל {email}",
    "Could not load {tag}{name}{endtag}" : "לא ניתן לטעון את {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "אירעה שגיאה בטעינה של {tag}{name}{endtag}",
    "Could not load your message" : "לא ניתן לטעון את ההודעה שלך",
    "Could not load the desired message" : "לא ניתן לטעון את ההודעה המבוקשת",
    "Could not load the message" : "לא ניתן לטעון את ההודעה",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
    "Nextcloud Mail" : "דוא״ל Nextcloud",
    "Save" : "שמירה",
    "Saved" : "נשמר",
    "Show all folders" : "הצגת כל התיקיות",
    "Collapse folders" : "קיווץ תיקיות",
    "Error while deleting account." : "שגיאה בזמן מחיקת חשבון.",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "An error occurred while uploading {fname}" : "אירעה שגיאה בעת ההעלאה של {fname}",
    "Reply" : "תגובה",
    "Send" : "שליחה",
    "Sending …" : "שולח...",
    "Message sent!" : "הודעה נשלחה!",
    "Server error" : "שגיאת שרת",
    "An unknown error occurred" : "אירעה שגיאה בלתי ידועה",
    "Opening HTML drafts is not supported yet." : "פתיחת טיוטות HTML לא נתמך עדיין.",
    "No writable calendars found" : "לא נמצאו יומנים ברי כתיבה",
    "Error while importing the calendar event" : "שגיאה בזמן יבוא של אירוע היומן",
    "Error while downloading calendar event" : "שגיאה בזמן הורדת אירוע יומן",
    "& others" : "& אחרים",
    "Error while loading messages." : "שגיאה בזמן העלאת הודעות.",
    "Error while refreshing messages." : "אירעה שגיאה בעת רענון ההודעות.",
    "Setting up your account" : "החשבון שלך מוגדר",
    "Inbox" : "דואר נכנס",
    "Sent" : "נשלח",
    "Drafts" : "טיוטות",
    "Archive" : "ארכיב",
    "Trash" : "פח אשפה",
    "Junk" : "דואר זבל",
    "All" : "הכל",
    "Favorites" : "מועדפים",
    "Auto detect failed. Please use manual mode." : "איתור אוטומטי נכשל. יש להשתמש במצב ידני.",
    "Updating account failed: " : "עדכון החשבון נכשל:",
    "Creating account failed: " : "יצירת חשבון נכשלה:",
    "Delete permanently" : "מחיקה לצמיתות",
    "IMAP web client" : "לקוח דפדפן IMAP",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "לקוח דוא״ל פשוט שמתחבר לשרת הדוא״ל שלך דרך IMAP ו־SMTP.",
    "Error loading message" : "שגיאה בהעלאת הודעה",
    "Settings" : "הגדרות",
    "Forwarding to %s" : "מועבר אל %s",
    "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
    "Redirect" : "הפנייה",
    "The link leads to %s" : "הקישור מוביל אל %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "אם אינך רוצה לבקר בדף זה, ניתן לחזור אל <a href=\"%s\">הדואר</a>.",
    "Continue to %s" : "ממשיך אל %s",
    "Delete account" : "מחיקת חשבון",
    "Try again" : "ניסיון חוזר",
    "New message" : "הודעה חדשה",
    "Account Settings" : "הגדרות חשבון",
    "Aliases" : "כינויים",
    "Mail address" : "כתובת דוא״ל",
    "Display Name" : "שם תצוגה",
    "Account" : "חשבון",
    "Toggle read" : "החלפת מצב קריאה",
    "Delete" : "מחיקה",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Speed up your Mail experience with these quick shortcuts." : "ניתן להאיץ את חוויית הדוא״ל שלך עם קיצורי המקלדת הזריזים האלו.",
    "Compose new message" : "כתיבת הודעה חדשה",
    "Newer message" : "הודעה חדשה יותר",
    "Older message" : "הודעה ישנה יותר",
    "Toggle star" : "החלפת מצב כוכב",
    "Toggle unread" : "החלפת מצב קריאה",
    "Search" : "חיפוש",
    "Refresh" : "רענון",
    "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
    "Name" : "שם",
    "Mail Address" : "כתובת דוא״ל",
    "Password" : "ססמה",
    "Manual configuration" : "תצורה ידנית",
    "IMAP Host" : "מארח IMAP",
    "IMAP security" : "אבטחת IMAP",
    "None" : "ללא",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "פתחת IMAP",
    "IMAP User" : "משתמש IMAP",
    "IMAP Password" : "ססמת IMAP",
    "SMTP Host" : "מארח SMTP",
    "SMTP security" : "אבטחת SMTP",
    "SMTP Port" : "פתחת SMTP",
    "SMTP User" : "משתמש SMTP",
    "SMTP Password" : "ססמת SMTP",
    "Connect" : "התחברות",
    "from" : "מאת",
    "to" : "אל",
    "cc" : "עותק",
    "bcc" : "עותק נסתר",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "נא לשים לב כי הדוא״ל מגיע מכתובת ללא מענה (noreply) ולכן התגובה שלך לא תיקרא.",
    "Subject" : "נושא",
    "Save all to Files" : "שמירת הכו לקבצים",
    "Add mail account" : "הוספת חשבון דוא״ל",
    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
    "No search results for" : "אין תוצאות לחיפוש",
    "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
    "Show images from this sender" : "הצגת תמונות מנמען זה",
    "Forward" : "העברה",
    "No messages in this folder" : "אין הודעות בתיקייה זו",
    "Upload attachment" : "העלאת קובץ מצורף",
    "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
    "Import into calendar" : "ייבוא ליומן",
    "Download attachment" : "הורדת קובץ מצורף",
    "Save to Files" : "שמירה לקבצים"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-mail-0.14.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/he.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "דואר",
    "Inbox" : "דואר נכנס",
    "Sent" : "נשלח",
    "Drafts" : "טיוטות",
    "Archive" : "ארכיב",
    "Trash" : "פח אשפה",
    "Junk" : "דואר זבל",
    "All" : "הכל",
    "Favorites" : "מועדפים",
    "Auto detect failed. Please use manual mode." : "איתור אוטומטי נכשל. יש להשתמש במצב ידני.",
    "Updating account failed: " : "עדכון החשבון נכשל:",
    "Creating account failed: " : "יצירת חשבון נכשלה:",
    "Delete permanently" : "מחיקה לצמיתות",
    "IMAP web client" : "לקוח דפדפן IMAP",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "לקוח דוא״ל פשוט שמתחבר לשרת הדוא״ל שלך דרך IMAP ו־SMTP.",
    "Name" : "שם",
    "Mail Address" : "כתובת דוא״ל",
    "Password" : "ססמה",
    "IMAP Host" : "מארח IMAP",
    "None" : "ללא",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "פתחת IMAP",
    "IMAP User" : "משתמש IMAP",
    "IMAP Password" : "ססמת IMAP",
    "SMTP Host" : "מארח SMTP",
    "SMTP Port" : "פתחת SMTP",
    "SMTP User" : "משתמש SMTP",
    "SMTP Password" : "ססמת SMTP",
    "Connect" : "התחברות",
    "Add mail account" : "הוספת חשבון דוא״ל",
    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "from" : "מאת",
    "to" : "אל",
    "cc" : "עותק",
    "bcc" : "עותק נסתר",
    "Subject" : "נושא",
    "Sending …" : "שולח...",
    "Message sent!" : "הודעה נשלחה!",
    "Send" : "שליחה",
    "Upload attachment" : "העלאת קובץ מצורף",
    "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "No messages in this folder" : "אין הודעות בתיקייה זו",
    "Delete" : "מחיקה",
    "Could not load your message" : "לא ניתן לטעון את ההודעה שלך",
    "Import into calendar" : "ייבוא ליומן",
    "Download attachment" : "הורדת קובץ מצורף",
    "Save to Files" : "שמירה לקבצים",
    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
    "Save all to Files" : "שמירת הכו לקבצים",
    "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
    "New message" : "הודעה חדשה",
    "Settings" : "הגדרות",
    "Show all folders" : "הצגת כל התיקיות",
    "Collapse folders" : "קיווץ תיקיות",
    "Speed up your Mail experience with these quick shortcuts." : "ניתן להאיץ את חוויית הדוא״ל שלך עם קיצורי המקלדת הזריזים האלו.",
    "Compose new message" : "כתיבת הודעה חדשה",
    "Newer message" : "הודעה חדשה יותר",
    "Older message" : "הודעה ישנה יותר",
    "Toggle star" : "החלפת מצב כוכב",
    "Toggle unread" : "החלפת מצב קריאה",
    "Search" : "חיפוש",
    "Refresh" : "רענון",
    "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
    "Nextcloud Mail" : "דוא״ל Nextcloud",
    "All inboxes" : "כל תיבות דואר נכנס",
    "Could not load {tag}{name}{endtag}" : "לא ניתן לטעון את {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "אירעה שגיאה בטעינה של {tag}{name}{endtag}",
    "Could not load the desired message" : "לא ניתן לטעון את ההודעה המבוקשת",
    "Could not load the message" : "לא ניתן לטעון את ההודעה",
    "Error loading message" : "שגיאה בהעלאת הודעה",
    "Forwarding to %s" : "מועבר אל %s",
    "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
    "Redirect" : "הפנייה",
    "The link leads to %s" : "הקישור מוביל אל %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "אם אינך רוצה לבקר בדף זה, ניתן לחזור אל <a href=\"%s\">הדואר</a>.",
    "Continue to %s" : "ממשיך אל %s"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
